==> cdc-issues-impl-0.21.0-sources.jar: cdc/issues/impl/ProfileImpl.java <==
package cdc.issues.impl;

import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

import cdc.issues.Params;
import cdc.issues.rules.Profile;
import cdc.issues.rules.Rule;
import cdc.util.lang.Checks;

public class ProfileImpl implements Profile {
    private String name;
    private Params metas = Params.NO_PARAMS;
    private final Set<Rule> enabledRules = new HashSet<>();
    private final Map<Rule, Params> rules = new HashMap<>();

    public ProfileImpl(String name) {
        this.name = name;
    }

    public ProfileImpl setName(String name) {
        this.name = name;
        return this;
    }

    public ProfileImpl setMetas(Params metas) {
        this.metas = metas;
        return this;
    }

    @Override
    public String getName() {
        return name;
    }

    @Override
    public Params getMetas() {
        return metas;
    }

    /**
     * Adds a rule with parameters and enable it.
     *
     * @param rule The rule.
     * @param params The parameters.
     * @return This object.
     */
    public ProfileImpl add(Rule rule,
                           Params params) {
        Checks.isNotNull(rule, "rule");
        Checks.isNotNull(params, "params");

        enabledRules.add(rule);
        rules.put(rule, params);
        return this;
    }

    /**
     * Adds a rule with no parameters and enable it.
     *
     * @param rule The rule.
     * @return This object.
     */
    public ProfileImpl add(Rule rule) {
        return add(rule, Params.NO_PARAMS);
    }

    /**
     * Removes a rule.
     *
     * @param rule The rule.
     * @return This object.
     */
    public ProfileImpl remove(Rule rule) {
        rules.remove(rule);
        enabledRules.remove(rule);
        return this;
    }

    /**
     * Enables or disables a rule.
     * <p>
     * If the rule is not declared, declares it.
     *
     * @param rule The rule.
     * @param enabled {@code true} if the rule must be enabled.
     * @return This object.
     */
    public ProfileImpl setEnabled(Rule rule,
                                  boolean enabled) {
        Checks.isNotNull(rule, "rule");

        if (enabled) {
            rules.putIfAbsent(rule, Params.NO_PARAMS);
            enabledRules.add(rule);
        } else {
            enabledRules.remove(rule);
        }
        return this;
    }

    @Override
    public Set<Rule> getRules() {
        return rules.keySet();
    }

    @Override
    public Set<Rule> getEnabledRules() {
        return enabledRules;
    }

    @Override
    public boolean isEnabled(Rule rule) {
        Checks.isNotNull(rule, "rule");
        return enabledRules.contains(rule);
    }

    @Override
    public Params getParams(Rule rule) {
        Checks.isNotNull(rule, "rule");
        return rules.get(rule);
    }
}

==> cdc-issues-impl-0.23.4-sources.jar: cdc/issues/impl/ProfileImpl.java <==
package cdc.issues.impl;

import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

import cdc.issues.Params;
import cdc.issues.rules.ConfiguredRule;
import cdc.issues.rules.Profile;
import cdc.issues.rules.Rule;
import cdc.util.lang.Checks;

public class ProfileImpl implements Profile {
    private String name;
    private Params metas = Params.NO_PARAMS;
    private final Set<Rule> enabledRules = new HashSet<>();
    private final Map<Rule, Params> rules = new HashMap<>();

    public ProfileImpl(String name) {
        this.name = name;
    }

    public ProfileImpl setName(String name) {
        this.name = name;
        return this;
    }

    public ProfileImpl setMetas(Params metas) {
        this.metas = metas;
        return this;
    }

    @Override
    public String getName() {
        return name;
    }

    @Override
    public Params getMetas() {
        return metas;
    }

    /**
     * Adds a rule with parameters and enable it.
     *
     * @param rule The rule.
     * @param params The parameters.
     * @return This object.
     */
    public ProfileImpl add(Rule rule,
                           Params params) {
        Checks.isNotNull(rule, "rule");
        Checks.isNotNull(params, "params");

        enabledRules.add(rule);
        rules.put(rule, params);
        return this;
    }

    /**
     * Adds a rule with no parameters and enable it.
     *
     * @param rule The rule.
     * @return This object.
     */
    public ProfileImpl add(Rule rule) {
        return add(rule, Params.NO_PARAMS);
    }

    /**
     * Removes a rule.
     *
     * @param rule The rule.
     * @return This object.
     */
    public ProfileImpl remove(Rule rule) {
        rules.remove(rule);
        enabledRules.remove(rule);
        return this;
    }

    /**
     * Enables or disables a rule.
     * <p>
     * If the rule is not declared, declares it.
     *
     * @param rule The rule.
     * @param enabled {@code true} if the rule must be enabled.
     * @return This object.
     */
    public ProfileImpl setEnabled(Rule rule,
                                  boolean enabled) {
        Checks.isNotNull(rule, "rule");

        if (enabled) {
            rules.putIfAbsent(rule, Params.NO_PARAMS);
            enabledRules.add(rule);
        } else {
            enabledRules.remove(rule);
        }
        return this;
    }

    @Override
    public Set<Rule> getRules() {
        return rules.keySet();
    }

    @Override
    public Set<ConfiguredRule> getConfiguredRules() {
        final Set<ConfiguredRule> set = new HashSet<>();
        for (final Map.Entry<Rule, Params> entry : rules.entrySet()) {
            set.add(new ConfiguredRule(entry.getKey(), entry.getValue()));
        }
        return set;
    }

    @Override
    public Set<Rule> getEnabledRules() {
        return enabledRules;
    }

    @Override
    public Set<ConfiguredRule> getEnabledConfiguredRules() {
        final Set<ConfiguredRule> set = new HashSet<>();
        for (final Map.Entry<Rule, Params> entry : rules.entrySet()) {
            if (isEnabled(entry.getKey())) {
                set.add(new ConfiguredRule(entry.getKey(), entry.getValue()));
            }
        }
        return set;
    }

    @Override
    public boolean isEnabled(Rule rule) {
        Checks.isNotNull(rule, "rule");
        return enabledRules.contains(rule);
    }

    @Override
    public Params getParams(Rule rule) {
        Checks.isNotNull(rule, "rule");
        return rules.get(rule);
    }
}
